@@ -3,12 +3,12 @@ import re
 from pathlib import Path
 from fastcore.script import Param, call_parse, store_true
 from fastcore.basics import listify
-import nbformat
 
 
 from nb_helpers.utils import (
     detect_imported_libs,
     git_local_repo,
+    git_main_name,
     search_string_in_nb,
     read_nb,
     find_nbs,
@@ -47,7 +47,8 @@ def search_code(nb, features=WANDB_FEATURES):
 def summary_nbs(
     path: Param("A path to nb files", str) = ".",
     wandb_features: Param("wandb features to identify, comma separated", str) = WANDB_FEATURES,
-    out_file: Param("Export to csv file", Path) = "summary.csv",
+    out_file: Param("Export to csv file", Path) = "summary_table.csv",
+    github_issue: Param("Creates a `github_issue.md` file ready to be put online", store_true) = True,
 ):
     path = Path(path)
     # out_file = (path.parent / out_file).with_suffix(".csv")
@@ -77,11 +78,13 @@ def summary_nbs(
             ", ".join(libs),
             str(colab_cell_idx) if colab_cell_idx != -1 else "",
         ]
-        colab_link = get_colab_url(nb_path)
+        colab_link = get_colab_url(nb_path, branch=git_main_name(nb_path))
         logger.writerow(row, colab_link)
-
     logger.finish()
 
+    if github_issue:
+        logger.create_github_issue()
+
 
 @call_parse
 def fix_nbs(
